@@ -949,6 +949,43 @@ c
    10 continue
       return
 c
+c       code for both increments equal to 1
+   20 do 30 i = 1,n
+        ztemp = zx(i)
+        zx(i) = zy(i)
+        zy(i) = ztemp
+   30 continue
+      return
+      end
+*----------------------------------------------------------------------|
+      subroutine  zswapy (n,m,zx,incx,zy,incy)
+c
+c     2019-07-01: NJM added m, I guess an integer like n
+c     interchanges two vectors.
+c     jack dongarra, 3/11/78.
+c
+      complex(kind=8) zx(1),zy(1),ztemp
+c
+      if(n.le.0)return
+      if(incx.eq.1.and.incy.eq.1)go to 20
+c
+c       code for unequal increments or equal increments not equal
+c         to 1
+c
+      ix = 1
+      iy = 1
+      if(incx.lt.0)ix = (-n+1)*incx + 1
+c      if(incy.lt.0)iy = (-n+1)*incy + 1
+      if(incy.lt.0)iy = (-m+1)*incy + 1
+      do 10 i = 1,n
+        ztemp = zx(ix)
+        zx(ix) = zy(iy)
+        zy(iy) = ztemp
+        ix = ix + incx
+        iy = iy + incy
+   10 continue
+      return
+c
 c       code for both increments equal to 1
    20 do 30 i = 1,n
         ztemp = zx(i)
